<?php


class MakeInfluence_PixelTracking_Model_Observer
{
	public function serverSideTracking(Varien_Event_Observer $observer)
	{
	    $logDate = new DateTime("now", new DateTimeZone('Europe/Copenhagen') );
	    $logName = $logDate->format('Y-m-d') . '-pixel-tracking.log';
		if(!$this->isEnabled()) {
            Mage::log('pixel-tracking not enabled', null, $logName, true);
			return null;
		}

		try {
            $orderIds = $observer->getData('order_ids');
            Mage::log('pixel-tracking start:: ', null, $logName, true);

            foreach($orderIds as $orderId) {
                $order = Mage::getModel('sales/order')->load($orderId);
                $subtotal = $order->getSubTotal() == 0.00 ? 0.00 : $this->getFormattedOrderTotal($order);
                $coupon = $order->getCouponCode();
                $date = new DateTime("now", new DateTimeZone('Europe/Copenhagen') );

                $params = [
                    'business_id' => $this->getBusinessId(),
                    'unique_id' => $orderId,
                    'value' => $subtotal,
                    'promotion_code' => $coupon,
                    'created_at' => $date->format('Y-m-d H:i:s'),
                    'currency' => $order->getOrderCurrencyCode(),
                    'ip' =>  $_SERVER['REMOTE_ADDR'],
                    'user_agent' => $_SERVER['HTTP_USER_AGENT'],
                    'http_referer' => $_SERVER["HTTP_REFERER"]

                ];

                $ch = curl_init();
                curl_setopt($ch, CURLOPT_URL, "https://system.makeinfluence.com/track-conversion");
                curl_setopt($ch, CURLOPT_POST, 1);
                curl_setopt($ch, CURLOPT_POSTFIELDS, $params);
                curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
                curl_setopt($ch, CURLOPT_HEADER, 1);
                $response = curl_exec($ch);
                $header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
                $headers = substr($response, 0, $header_size);
                $body = substr($response, $header_size);
                curl_close($ch);

                $_responseOutput = [];
                $_responseOutput['response'] = $response;
                $_responseOutput['header_size'] = $header_size;
                $_responseOutput['headers'] = $headers;
                $_responseOutput['body'] = $body;

                Mage::log(print_r($_responseOutput,true), null, $logName, true);
                Mage::log(print_r($params,true), null, $logName, true);
            }

            Mage::log('pixel-tracking finished:: ', null, $logName, true);
        } catch (Exception $exception) {
            Mage::log($exception->getMessage(), null, $logName, true);
            Mage::log($exception->getTraceAsString(), null, $logName, true);
            Mage::log('pixel-tracking error:: ', null, $logName, true);
        }

		return $this;
	}

	public function getFormattedOrderTotal($order)
	{
		return number_format($order->getSubTotal(), 2, '.','');
	}

	private function isEnabled()
	{
		return Mage::getStoreConfig('configuration/settings_group/enable', Mage::app()->getStore()) == 1;
	}

	private function getBusinessId()
	{
		return Mage::getStoreConfig('configuration/settings_group/business_id', Mage::app()->getStore());
	}
}